--[[
@title:       fillTypeOverlays
@description: Adds new overlays for fillTypes.
@author:      Jakob Tischler
@date:        17 Jan 2014
@version:     0.3

@contact:     jakobgithub -tt- gmail -dot- com
]]

fillTypeOverlays = {}
fillTypeOverlays.modDir = g_currentModDirectory;
fillTypeOverlays.overlayDir = fillTypeOverlays.modDir .. 'overlays/';
addModEventListener(fillTypeOverlays);

function fillTypeOverlays:loadMap(name)
	print("## fillTypeOverlays v0.3 by Jakob Tischler loaded");

	self.debugActive = false;

	self.overlayDir = fillTypeOverlays.modDir .. 'overlays/';
	self.overlaysFiles = Files:new(self.overlayDir);

	self.addToDrawFn = {
		[Fillable.FILLTYPE_FERTILIZER] = 'Sprayer';
		[Fillable.FILLTYPE_FUEL] = 'FuelTrailer';
		[Fillable.FILLTYPE_LIQUIDMANURE] = 'Sprayer';
		[Fillable.FILLTYPE_MANURE] = 'Sprayer';
		-- [Fillable.FILLTYPE_SEEDS] = 'SowingMachine'; --not needed/possible: seeds has its own seed type overlay
	};

	local renderFillTypeOverlay = function(self)
		if self.isClient and self.currentFillType and self.currentFillType ~= Fillable.FILLTYPE_UNKNOWN and self.fillLevel > 0 and g_currentMission.fillTypeOverlays[self.currentFillType] then
			g_currentMission:setFillTypeOverlayFillType(self.currentFillType);
		end;
	end;

	for i=1,Fillable.NUM_FILLTYPES do
		local desc = Fillable.fillTypeIndexToDesc[i];
		local name = desc.name;
		local filePath = Utils.getFilename(name .. '.dds', self.overlayDir);
		if fileExists(filePath) then
			self:dbg(string.format('\tfillType %d (%q / %q): filename="%s.dds"', i, name, desc.nameI18N, name));
			if g_currentMission.fillTypeOverlays[i] then
				self:dbg(string.format('\t\tdelete existing overlay (id %d)', g_currentMission.fillTypeOverlays[i].overlayId));
				g_currentMission.fillTypeOverlays[i]:delete();
			end;
			g_currentMission:addFillTypeOverlay(i, filePath);
			print(string.format('\tfillType overlay "%s.dds" loaded for fillType %q (%q)', name, name, desc.nameI18N));

			if self.addToDrawFn[i] ~= nil then
				_G[ self.addToDrawFn[i] ].draw = Utils.prependedFunction(_G[ self.addToDrawFn[i] ].draw, renderFillTypeOverlay);
				self:dbg(string.format('\t\tadd "setFillTypeOverlayFillType()" to "%s:draw()"', self.addToDrawFn[i]));
			end;
		end;
	end;

	if self.debugActive then
		for i,overlayData in pairs(g_currentMission.fillTypeOverlays) do
			self:dbg(string.format('fillType %d (%q / %q) has overlay', i, Fillable.fillTypeIntToName[i], Fillable.fillTypeIndexToDesc[i].nameI18N));
		end;
	end;

	if (self.initialized) then
		return;
	end;

	self.initialized = true;
end;

function fillTypeOverlays:deleteMap()
	self.initialized = false;
end;

function fillTypeOverlays:keyEvent(unicode, sym, modifier, isDown)
end;

function fillTypeOverlays:update(dt)
end;

function fillTypeOverlays:updateTick(dt)
end;

function fillTypeOverlays:draw()
end;

function fillTypeOverlays:mouseEvent(posX, posY, isDown, isUp, button)
end;

function fillTypeOverlays:dbg(str)
	if self.debugActive then
		print(tostring(str));
	end;
end;
